package com.example.camel;

import java.util.Collection;

import jakarta.validation.Valid;
import jakarta.ws.rs.Consumes;
import jakarta.ws.rs.GET;
import jakarta.ws.rs.PUT;
import jakarta.ws.rs.Path;
import jakarta.ws.rs.PathParam;
import jakarta.ws.rs.Produces;
import jakarta.ws.rs.core.MediaType;
import jakarta.ws.rs.core.Response;

/**
 * Service interface for managing users.
 */
public interface UserService {

    /**
     * Find a user by the given ID
     *
     * @param id
     *            the ID of the user
     * @return the user, or <code>null</code> if user not found.
     */
    @GET
    @Path("/user/{id}")
    @Produces(MediaType.APPLICATION_JSON)
    User findUser(@PathParam("id") Integer id);

    /**
     * Find all users
     *
     * @return a collection of all users
     */
    @GET
    @Path("/user")
    @Produces(MediaType.APPLICATION_JSON)
    Collection<User> findUsers();

    /**
     * Update the given user
     *
     * @param user
     *            the user
     */
    @PUT
    @Path("/user")
    @Consumes(MediaType.APPLICATION_JSON)
    Response updateUser(@Valid User user);

}